//---------------------------------------------------------------------------------
/// \file	SimpleCommand.cpp
/// \author	Rob Bateman [robthebloke@hotmail.com]
/// \date	2-7-2004
/// \brief	This is the simplest possible example of how to write a mel command
///			that can be added into Maya via a plugin. You can call the command 
///			from mel by typing, "SimpleCommand". This simply executes a mel call 
///			via MGlobal::executeCommand to create a sphere.
///	
//---------------------------------------------------------------------------------

// include any maya headers we need.
#include <maya/MSimple.h>
#include <maya/MGlobal.h>

//---------------------------------------------------------------------------------
// Use a helper macro to register a command with Maya.  This creates and
// registers a command that does not support undo or redo.  The
// created class derives off of MPxCommand.
//
DeclareSimpleCommand( SimpleCommand, "A simple mel function example", "4.0");

//---------------------------------------------------------------------------------
/// \brief	This function impliments our very first simple command plugin.
/// \param	args - the argument list that was passes to the command from MEL
/// \return	MS::kSuccess - command succeeded
///			MS::kFailure - command failed (returning this value will cause the
///         	           MEL script that is being run to terminate unless the
///         	           error is caught using a "catch" statement.
///
MStatus SimpleCommand::doIt( const MArgList& args )

{
	// the return status
	MStatus stat = MS::kSuccess;

	// we can actually execute mel script by using MGlobal::executeCommand. In
	// this case all out function does is execute the mel script call to create
	// a sphere.
	//
	stat = MGlobal::executeCommand("sphere");

	// check for any errors that occured
	if(stat==MS::kSuccess) {

		// send a nice result message back to the user
		setResult("The sphere is alive!");
	}
	else {

		// oooh dear, something went wrong.
		displayError("[ERROR] could not create a sphere");
	}
	return stat;
}
